@@ -1,11 +1,9 @@
 import threading
 import time
 from collections import Counter
-from typing import Dict
-from typing import List
-from typing import Tuple
+from typing import Dict, List, Tuple
 
-from .base import Storage
+from .base import MovingWindowSupport, Storage
 
 
 class LockableEntry(threading._RLock):
@@ -14,10 +12,10 @@ class LockableEntry(threading._RLock):
     def __init__(self, expiry):
         self.atime = time.time()
         self.expiry = self.atime + expiry
-        super(LockableEntry, self).__init__()
+        super().__init__()
 
 
-class MemoryStorage(Storage):
+class MemoryStorage(Storage, MovingWindowSupport):
     """
     rate limit storage using :class:`collections.Counter`
     as an in memory storage for fixed and elastic window strategies,
@@ -33,7 +31,7 @@ class MemoryStorage(Storage):
         self.events: Dict[str, List[LockableEntry]] = {}
         self.timer = threading.Timer(0.01, self.__expire_events)
         self.timer.start()
-        super(MemoryStorage, self).__init__(uri)
+        super().__init__(uri)
 
     def __expire_events(self):
         for key in list(self.events.keys()):
@@ -89,13 +87,11 @@ class MemoryStorage(Storage):
         self.expirations.pop(key, None)
         self.events.pop(key, None)
 
-    def acquire_entry(self, key: str, limit: int, expiry: int, no_add=False) -> bool:
+    def acquire_entry(self, key: str, limit: int, expiry: int) -> bool:
         """
         :param key: rate limit key to acquire an entry in
         :param limit: amount of entries allowed
         :param expiry: expiry of the entry
-        :param no_add: if False an entry is not actually acquired
-         but instead serves as a 'check'
         """
         self.events.setdefault(key, [])
         self.__schedule_expiry()
@@ -108,9 +104,7 @@ class MemoryStorage(Storage):
         if entry and entry.atime >= timestamp - expiry:
             return False
         else:
-            if not no_add:
-                self.events[key].insert(0, LockableEntry(expiry))
-
+            self.events[key].insert(0, LockableEntry(expiry))
             return True
 
     def get_expiry(self, key: str) -> int:
