@@ -1,7 +1,7 @@
 import urllib.parse
+from typing import Any, Dict, Optional
 
 from ..errors import ConfigurationError
-from ..util import get_dependency
 from .redis import RedisStorage
 
 
@@ -9,36 +9,53 @@ class RedisSentinelStorage(RedisStorage):
     """
     Rate limit storage with redis sentinel as backend
 
-    Depends on `redis-py` library
+    Depends on the :pypi:`redis` package
     """
 
     STORAGE_SCHEME = ["redis+sentinel"]
+    """The storage scheme for redis accessed via a redis sentinel installation"""
 
-    def __init__(self, uri: str, service_name: str = None, **options):
+    DEFAULT_OPTIONS = {
+        "socket_timeout": 0.2,
+    }
+    "Default options passed to :class:`~redis.sentinel.Sentinel`"
+
+    DEPENDENCIES = ["redis.sentinel"]
+
+    def __init__(
+        self,
+        uri: str,
+        service_name: str = None,
+        sentinel_kwargs: Optional[Dict[str, Any]] = None,
+        **options
+    ):
         """
         :param uri: url of the form
-         `redis+sentinel://host:port,host:port/service_name`
-        :param service_name, optional: sentinel service name
-         (if not provided in `uri`)
+         ``redis+sentinel://host:port,host:port/service_name``
+        :param service_name: sentinel service name
+         (if not provided in :attr:`uri`)
+        :param sentinel_kwargs: kwargs to pass as
+         :attr:`sentinel_kwargs` to :class:`redis.sentinel.Sentinel`
         :param options: all remaining keyword arguments are passed
          directly to the constructor of :class:`redis.sentinel.Sentinel`
         :raise ConfigurationError: when the redis library is not available
          or if the redis master host cannot be pinged.
         """
 
-        if not get_dependency("redis"):
-            raise ConfigurationError(
-                "redis prerequisite not available"
-            )  # pragma: no cover
+        super(RedisStorage, self).__init__()
 
         parsed = urllib.parse.urlparse(uri)
         sentinel_configuration = []
-        password = None
+        sentinel_options = sentinel_kwargs.copy() if sentinel_kwargs else {}
 
+        if parsed.username:
+            sentinel_options["username"] = parsed.username
         if parsed.password:
-            password = parsed.password
+            sentinel_options["password"] = parsed.password
 
-        for loc in parsed.netloc[parsed.netloc.find("@") + 1:].split(","):
+        sep = parsed.netloc.find("@") + 1
+
+        for loc in parsed.netloc[sep:].split(","):
             host, port = loc.split(":")
             sentinel_configuration.append((host, int(port)))
         self.service_name = (
@@ -48,33 +65,33 @@ class RedisSentinelStorage(RedisStorage):
         if self.service_name is None:
             raise ConfigurationError("'service_name' not provided")
 
-        options.setdefault("socket_timeout", 0.2)
-
-        self.sentinel = get_dependency("redis.sentinel").Sentinel(
-            sentinel_configuration, password=password, **options
+        self.sentinel = self.dependencies["redis.sentinel"].Sentinel(
+            sentinel_configuration,
+            sentinel_kwargs=sentinel_options,
+            **{**self.DEFAULT_OPTIONS, **options}
         )
         self.storage = self.sentinel.master_for(self.service_name)
         self.storage_slave = self.sentinel.slave_for(self.service_name)
         self.initialize_storage(uri)
-        super(RedisStorage, self).__init__()
 
     def get(self, key: str) -> int:
         """
         :param key: the key to get the counter value for
         """
 
-        return super(RedisStorage, self)._get(key, self.storage_slave)
+        return super()._get(key, self.storage_slave)
 
     def get_expiry(self, key: str) -> int:
         """
         :param key: the key to get the expiry for
         """
 
-        return super(RedisStorage, self)._get_expiry(key, self.storage_slave)
+        return super()._get_expiry(key, self.storage_slave)
 
     def check(self) -> bool:
         """
-        check if storage is healthy
+        Check if storage is healthy by calling :class:`aredis.StrictRedis.ping`
+        on the slave.
         """
 
-        return super(RedisStorage, self)._check(self.storage_slave)
+        return super()._check(self.storage_slave)
