@@ -1,13 +1,10 @@
 """
-rate limiting strategies
+Rate limiting strategies
 """
 
-from abc import ABCMeta, abstractmethod
 import weakref
-from typing import Dict
-from typing import Tuple
-from typing import Type
-from typing import Union
+from abc import ABCMeta, abstractmethod
+from typing import Dict, Tuple, Type, Union
 
 from .limits import RateLimitItem
 from .storage import Storage
@@ -20,34 +17,33 @@ class RateLimiter(metaclass=ABCMeta):
     @abstractmethod
     def hit(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        creates a hit on the rate limit and returns True if successful.
+        Consume the rate limit
 
-        :param item: a :class:`RateLimitItem` instance
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param item: The rate limit item
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         """
         raise NotImplementedError
 
     @abstractmethod
     def test(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        checks  the rate limit and returns True if it is not
-        currently exceeded.
+        Check the rate limit without consuming from it.
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+          instance of the limit
         """
         raise NotImplementedError
 
     @abstractmethod
     def get_window_stats(self, item: RateLimitItem, *identifiers) -> Tuple[int, int]:
         """
-        returns the number of requests remaining and reset of this limit.
+        Query the reset time and remaining amount for the limit
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         :return: (reset time, remaining)
         """
         raise NotImplementedError
@@ -58,7 +54,7 @@ class RateLimiter(metaclass=ABCMeta):
 
 class MovingWindowRateLimiter(RateLimiter):
     """
-    Reference: :ref:`moving-window`
+    Reference: :ref:`strategies:moving window`
     """
 
     def __init__(self, storage: Storage):
@@ -69,15 +65,16 @@ class MovingWindowRateLimiter(RateLimiter):
                 "MovingWindowRateLimiting is not implemented for storage "
                 "of type %s" % storage.__class__
             )
-        super(MovingWindowRateLimiter, self).__init__(storage)
+        super().__init__(storage)
 
     def hit(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        creates a hit on the rate limit and returns True if successful.
+        Consume the rate limit
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
+        :return: (reset time, remaining)
         """
 
         return self.storage().acquire_entry(  # type: ignore
@@ -86,12 +83,11 @@ class MovingWindowRateLimiter(RateLimiter):
 
     def test(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        checks  the rate limit and returns True if it is not
-        currently exceeded.
+        Check if the rate limit can be consumed
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         """
 
         return (
@@ -108,8 +104,8 @@ class MovingWindowRateLimiter(RateLimiter):
         returns the number of requests remaining within this limit.
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         :return: tuple (reset time, remaining)
         """
         window_start, window_items = self.storage().get_moving_window(  # type: ignore
@@ -122,16 +118,16 @@ class MovingWindowRateLimiter(RateLimiter):
 
 class FixedWindowRateLimiter(RateLimiter):
     """
-    Reference: :ref:`fixed-window`
+    Reference: :ref:`strategies:fixed window`
     """
 
     def hit(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        creates a hit on the rate limit and returns True if successful.
+        Consume the rate limit
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         """
 
         return (
@@ -141,23 +137,22 @@ class FixedWindowRateLimiter(RateLimiter):
 
     def test(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        checks  the rate limit and returns True if it is not
-        currently exceeded.
+        Check if the rate limit can be consumed
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         """
 
         return self.storage().get(item.key_for(*identifiers)) < item.amount
 
     def get_window_stats(self, item: RateLimitItem, *identifiers) -> Tuple[int, int]:
         """
-        returns the number of requests remaining and reset of this limit.
+        Query the reset time and remaining amount for the limit
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         :return: (reset time, remaining)
         """
         remaining = max(0, item.amount - self.storage().get(item.key_for(*identifiers)))
@@ -168,16 +163,16 @@ class FixedWindowRateLimiter(RateLimiter):
 
 class FixedWindowElasticExpiryRateLimiter(FixedWindowRateLimiter):
     """
-    Reference: :ref:`fixed-window-elastic`
+    Reference: :ref:`strategies:fixed window with elastic expiry`
     """
 
     def hit(self, item: RateLimitItem, *identifiers) -> bool:
         """
-        creates a hit on the rate limit and returns True if successful.
+        Consume the rate limit
 
         :param item: The rate limit item
-        :param identifiers: variable list of strings to uniquely identify the
-         limit
+        :param identifiers: variable list of strings to uniquely identify this
+         instance of the limit
         """
 
         return (
